@@ -149,7 +149,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         logger.info(f"Browser {self.browser_type} launched")
 
     async def _plan_context_rotation(self) -> None:
-        logger.warning("Re create browser: Before acquire")
+        logger.info("Re create browser: Before acquire")
         await self.context_semaphore.acquire()
         logger.info("Re create browser: After acquire")
 
